function [mean,var] = average(x,dim)
    % [function] Compute averages
    % :returns: the mean and variance of an array *x*
    % :param x: input array. Complex values are treated as points in 2D.
    % :param dim: dimension of *x* along which the sums are computed.
    %   Default is the first dimension with more than one element. 
    %
    % Note that, if x is complex, the variance of the distance to the
    % barycenter is real(var)+imag(var).
    %
    % Algorithm:
    % `https://en.wikipedia.org/wiki/Algorithms_for_calculating_variance`
    if nargin==1
        dim = 1;
        while size(x,dim)==1 
            dim = dim+1;
        end
    end
    n = size(x,dim);
    SUM = sum(x,dim);
    if nargout>1
        if isreal(x)
            SSQ = sum(x.^2,dim);
            var = ( SSQ - (SUM.^2)/n )/n;
        else
            realSSQ = sum(real(x).^2,dim);
            imagSSQ = sum(imag(x).^2,dim);
            realvar = ( realSSQ - (real(SUM).^2)/n )/n;
            imagvar = ( imagSSQ - (imag(SUM).^2)/n )/n;
            var = realvar + 1i*imagvar;
        end
    end
    mean = SUM/n;
end
