function clean_start( varargin )
    % function to start a Sparsimatics script in a clean matlab
    % environment. Optionally sets Sparsimatics.Verbosity. Also calls
    % report_git_status to allow reproduction of a script in exactly the
    % same environment.
    % 
    % :param double verbosity: integer passed to
    %   Sparsimatics.Verbosity(verbosity). Optional, default=0.
    % :param char mfile: The name of the mfile that called clean_start.
    %   This is automatically provided if you call clean_start with the
    %   argument `mfilename` , or `mfilename('fullpath')` .
    %   
    % The order of parameters is immaterial. Their disambiguation is based 
    % on the type.
    
    close all
    clc

    verbosity = 0;
    mfile = '';
    for iargin=1:nargin
        argin = varargin{iargin};
        if is_integer(argin)
            verbosity = argin;
        elseif ischar(argin)
            mfile = argin;
        end
    end

    if ~isempty(mfile)
        cprintf('SystemCommands','Executing script:\n  %s',mfile);
    end
    Sparsimatics.Verbosity(verbosity);

    report_git_status;    
end