function tf = is_integer( value )
    % [function] This function tests whether *value* is an integer value. 
    %
    % :param value: the number to be tested.
    % :return: logical
    %
    % In Matlab the statement::
    %
    %   a = 2;
    %   
    % yields an object of type 'double', and hence the test ``isinteger(a)`` fails a bit
    % unexpectedly:: 
    %
    %   >> class(a)
    %   ans =
    %   double
    %   >> isinteger(a)
    %   ans =
    %        0
    %
    % whereas this function succeeds::
    %
    %   >> tf = is_integer(a);
    %   ans =
    %        1
    %
    % The arguments themselves are not type-checked.
    % 
    tf = isnumeric(value);
    if ~tf
        return
    end
    tf = isequal(fix(value),value);
end

