function tf = is_physical( time_scale )
    % [function] This function tests whether the time_scale string matches 'p[hysical]' or
    % 'n[ormalized]'. ('normalis[ed]' is accepted too). If the string matches neither, an error
    % message is produced.
    % 
    % :param time_scale: a string indicating a physical [unit=s] or normalized [unit=1] time scale, 'p' or 'n' in its simplest form. 
    % :return: true or false (logical).
    %
    if ~ischar(time_scale)
        Sparsimatics.Error( 'function is_physical( time_scale )', 'Expecting string argument,got ''%s''.',class(time_scale) );
    end
    
    n = length(time_scale);
    if strncmpi(time_scale,'physical',n)
        tf = true;
    elseif strncmpi(time_scale,'normalized',n)
        tf = false;
    elseif strncmpi(time_scale,'normalised',n)
        tf = false;
    else
        Sparsimatics.Error( 'function is_physical( time_scale )' ...
            ,['time_scale must be ''n[ormalized]'' or ''p[hysical]'', got ''%s''.\n' ...
              '! The comparison is case insensitive, characters between brackets are optional but must match if provided.'] ...
            , time_scale ...
            );
    end

end

