function figure_handle = plot_clusters( varargin )
    % function PlotClusterinResult(X, IDX)

    fa = Parameters('plot_clusters:Plot the clusters in the complex plane.' ...
           , {'points    :double: base terms, 1D complex, or 2D real' , Required ...
             ,'cluster   :@is_integer&@is_positive: cluster index'    , Required ...
             ,'row       :@is_integer&@is_positive: row index'        , 0  ...
             ,'plot_noise:logical: do not plot noise'               , true  ...
             } ...
           , varargin{:} ...
          );
    cl = fa.p.cluster.value;
    
    size_points = size(fa.p.points.value);
    if size_points(1)==1 || size_points(2)==1% complex 1D
        xy = zeros(numel(fa.p.points.value),2);
        xy(:,1) = real(fa.p.points.value);
        xy(:,2) = imag(fa.p.points.value);
    elseif size_points(2)==2 % real 2D
        xy = fa.p.points.value;
    else
        Sparsimatics.Error('plot_clusters(b,cluster[,row])' ...
          , 'b must be 1D complex array or a 2D real array.' ...
          );
    end
    
    rw = fa.p.row.value; 
    if isscalar(rw) && rw==0
        rw = ones(size(xy,1),1);
        nrows = 1;
    else
        nrows = max(rw);
    end
    
    figure_handle = figure;
    
    nclusters = max(cl);
    colors=distinguishable_colors(nclusters+nrows); % for white background
    legend_entries = {};
    
    % we first plot everything that has a legend entry, than everything
    % that doesn't.

    % plot the cluster circles
    for c=1:nclusters
        subset = (cl==c);
        xyc = xy(subset,:);
        nc = length(xyc);
        if nc>0
            legend_entries = [legend_entries sprintf('cluster%d (#=%d)',c,numel(xyc)/2)]; %#ok<AGROW>
            center = sum(xyc)/nc;
            radius = max(0.05,2*sqrt(max(sum((xyc-center).^2,2))));
            draw_circle(center,radius,colors(c,:));
            hold on
        end
    end
    if fa.p.plot_noise.value
        % plot the noise
        subset = (cl==0); 
        xyn = xy(subset,:);
        if ~isempty(xyn)
            if nrows==1
                legend_entries = [legend_entries sprintf('Noise (#=%d)',numel(xyn)/2)];
                plot( xyn(:,1), xyn(:,2), '.'               ...
                    , 'MarkerSize', 8                       ...
                    , 'Color'     , colors(nclusters+1,:)   ...
                    );
                hold on;
            else
                rwn = rw(subset);
                for r=1:nrows
                    xynr = xyn(rwn==r,:);
                    if ~isempty(xynr)
                        legend_entries = [legend_entries sprintf('Noise row%d (#=%d)',r,numel(xynr)/2)]; %#ok<AGROW>
                        plot( xynr(:,1), xynr(:,2), '.'   ...
                            , 'MarkerSize', 8             ...
                            , 'Color'     , colors(nclusters+r,:)   ...
                            );
                        hold on;
                    end
                end
            end
        end
    end
    
    if ~isempty(legend_entries)
        legend( legend_entries ...
              , 'Location'  , 'NorthEastOutside' ...
              , 'AutoUpdate', 'off' ...
              );
    end
    
    % plot the cluster point connections
     for c=1:nclusters
        subset = (cl==c);
        xyc = xy(subset,:);
        if ~isempty(xyc)
            plot( xyc(:,1), xyc(:,2), '-'   ...
                , 'MarkerSize', 8             ...
                , 'Color'     , colors(c,:)   ...
                );
            hold on
        end
    end
    % plot the cluster point connections
    subset = (cl~=0);
    xyc = xy(subset,:);
    if ~isempty(xyc)
        rwc = rw(subset,:);
        for r=1:nrows
            subset = (rwc==r);
            xycr = xyc(subset,:);
            plot( xycr(:,1), xycr(:,2), 'o'   ...
                , 'MarkerSize', 8             ...
                , 'Color'     , colors(nclusters+r,:)   ...
                );
            hold on
        end
    end

    plot_unit_circle( '--width', 1.2 );
end

