function tf = validate_value(value,typecheck,recursion_level)
    % [object method] Test if value stands the typecheck
    %
    % :param value: value to test
    % :param typecheck: a typecheck description: either a class name (e.g.
    %   'MyClass'), a function name (e.g. '@my_function') or a cell list
    %   thereof. On the first level, the cell list entries are OR-ed, on
    %   the second level, they are AND-ed.
    % :returns: true (success), false (failure)
    %
    
    if nargin==2
        recursion_level =  1;
    end
    
    if ischar( typecheck )
        if typecheck(1)=='@'
            % function handle
            fh = eval(typecheck);
            tf = fh(value);
        else
            % class
            tf = isa(value,typecheck);
        end
    elseif iscell(typecheck)
        switch recursion_level
            case 1 % combine using operator ||
                for i=1:numel(typecheck)
                    tf = validate_value(value,typecheck{i},recursion_level+1);
                    if tf 
                        break % answer is true
                    end
                end     
                
            case 2 % combine using operator &&
                tf = validate_value(value,typecheck{1},recursion_level+1);
                if tf % else the answer is false
                    for i=2:numel(typecheck)
                        tf = tf && validate_value(value,typecheck{i},recursion_level+1);
                        if ~tf 
                            break % answer is false
                        end
                    end
                end
                
            otherwise
                Sparsimatics.Error('validate_value(value,typecheck[,recursion_level])'...
                  , 'Unexpected recursion level: %d.' ...
                  , recursion_level_ ...
                  );
        end
    end
end
