function figure_handle = plot_components( varargin )
    % [function] Plot :math:`(\omega_i,|\alpha_i|)` for an arbitrary number of
    % *MultiExponentialParameters* objects.
    %
    % :param components: one or more *MultiExponentialParameters* objects.
    % :return: a handle to the created figure.
    % 
    % `examples <tutorial_Visualization.html>`_
    %
    fa = Parameters ...
           ( 'plot_components:Plot the magnitude of the coefficients vs the frequency.' ...
           , {'components_list:MultiExponentialParameters:parameter sets to plot:+', Required } ...
           , varargin{:} ...
           );

    figure_handle = figure('Tag' , 'plot_components' ...
                          ,'Name', 'plot_components' ...
                          );

    legend_ = {};
    n = length(fa.p.components_list.value);
    for i = 1:n
        legend_{i} = num2str(i); %#ok<AGROW>
        if i==1
            plot_symbol = '+r';
        else
            plot_symbol = 'o';
            hold on;
        end
        parameters = fa.p.components_list.value{i};
        phi       = log( parameters.b ) * parameters.sampling_frequency;
        omega     = imag( phi )/(2*pi);
        abs_alpha = abs( parameters.c );
        plot(omega,abs_alpha,plot_symbol);
    end
    if n>1
        legend(legend_{:});
    end
    xlabel('\omega')
    ylabel('|\alpha|')
    
end

