function [figure_handle,complex_fft,frequency_domain] = plot_signal_FFT( varargin )
    % [function] Compute and plot the Discrete Fourier transform of
    % *signal*. 
    %
    % :param signal: the *Signal* object to be plotted.
    % :param key,value=char [plot-what]: a string containing the characters 'R' (=plot real part), 'I' (=plot imaginary part), 'M' (= plot magnitude). An empty string or '*' causes all three to be plotted. 
    % :param key,value=char [plot-symbol]: symbol used by the matlab plot function. default = '-'.
    % :param key,value=char [shift]: frequency domain = [0,fs/2] (default), [-pi,pi] if true. 
    % :param key,value=char [scale]: amplitude scaling: 'lin' (=default) | 'log' | 'db'. 
    % :return: handle of the created figure, and the (complex) DFT.
    %
    % `examples <tutorial_Visualization.html>`_
    %
    fa = Parameters ...
           ('plot_signal FFT:Compute the Fourier transform of an input signal, and plot it in the frequency domain.' ...
           , {'signal:Signal: signal to plot'                            , Required ...
             ,'plot_what:char: ''RIM'''                                  , '*'      ...
             ,'plot_symbol:char'                                         , '-'      ...
             ,'nsamples:@is_minus1_or_fraction_or_positive_integer:nsamples to use', -1      ...
             ,'shift:logical:apply fftshift'                             , true      ...
             ,'scale:char:''lin''|''log''|''db'''                        , 'lin'    ...
             ,'use_current_figure:logical:plot in current figure if true', false    ...
             } ...
          , varargin{:} ...
          );
    plot_what = fa.p.plot_what.value;
    
    if isempty(plot_what)
        plot_what = '*';
    end

    if isempty(plot_what)
        plot_what = '*';
    end
    plot_all = contains(plot_what,'*');
    if plot_all
        plot_re = true;
        plot_im = true;
        plot_mg = true;
    else
        plot_re= contains(plot_what,'R');
        plot_im= contains(plot_what,'I');
        plot_mg= contains(plot_what,'M');
        if ~plot_re && ~plot_im && ~plot_mg
            plot_re = true;
            plot_im = true;
            plot_mg = true;
        end
    end

    nsamples = apply_fraction_or_min( fa.p.nsamples.value, fa.p.signal.value.length() );
    complex_fft = fft(fa.p.signal.value.samples(1:nsamples))/nsamples;
    if fa.p.shift.value
        complex_fft = fftshift(complex_fft);
        frequency_domain = linspace(-1,1,nsamples)*(fa.p.signal.value.sampling_frequency/2);
    else
        frequency_domain = linspace(0,1,nsamples)*(fa.p.signal.value.sampling_frequency);
    end
    
    reFFT = real( complex_fft );
    imFFT = imag( complex_fft );
    mgFFT = abs ( complex_fft );
    scale_label = '%s';
    if ~strcmp(fa.p.scale.value,'lin') % 'log' or 'db'
        reFFT = log10(reFFT);
        imFFT = log10(imFFT);
        mgFFT = log10(mgFFT);
        scale_label = 'log10(%s)';
    end
    if strcmp(fa.p.scale.value,'db')
        reFFT = 20*reFFT;
        imFFT = 20*imFFT;
        mgFFT = 20*mgFFT;
        scale_label = '%s [db]';
    end    
    if fa.p.use_current_figure.value
        figure_handle = gcf;
        hold on
    else
        figure_handle = figure('Tag','plot_signal_FFT');
    end
    set(figure_handle,'Position',[0,0,500,1000])

    title_ = sprintf('Fourier transform of "%s"', fa.p.signal.value.label );
    n_subplots = double( int16(plot_re)+int16(plot_im)+int16(plot_mg) );
    i_subplot = 0;
    
    if plot_re
        i_subplot = i_subplot+1;
        subplot(n_subplots,1,i_subplot)
        plot( frequency_domain, reFFT, fa.p.plot_symbol.value );
        if ~fa.p.use_current_figure.value
            title(title_)
        end
        xlabel('Hz')
        ylabel(sprintf(scale_label,'Re'))
    end
    
    if plot_im
        i_subplot = i_subplot+1;
        subplot(n_subplots,1,i_subplot)
        plot( frequency_domain, imFFT, fa.p.plot_symbol.value );
        if ~fa.p.use_current_figure.value
            title(title_)
        end
        xlabel('Hz')
        ylabel(sprintf(scale_label,'Im'))
    end
    
    if plot_mg
        i_subplot = i_subplot+1;
        subplot(n_subplots,1,i_subplot)
        plot( frequency_domain, mgFFT, fa.p.plot_symbol.value );
        if ~fa.p.use_current_figure.value
            title(title_)
        end
        xlabel('Hz')
        ylabel(sprintf(scale_label,'magnitude'))
    end    

end
